@@ -29,13 +29,6 @@ sub qs($) {
     Menlo::Util::shell_quote($_[0]);
 }
 
-sub agent {
-    my $self = shift;
-    my $agent = "cpanminus/$VERSION";
-    $agent .= " perl/$]" if $self->{report_perl_version};
-    $agent;
-}
-
 sub determine_home {
     my $class = shift;
 
@@ -55,6 +48,7 @@ sub new {
     my $class = shift;
 
     my $self = bless {
+        name => "Menlo",
         home => $class->determine_home,
         cmd  => 'install',
         seen => {},
@@ -418,7 +412,7 @@ sub setup_home {
         }
     }
 
-    $self->chat("cpanm (Menlo) $VERSION on perl $] built for $Config{archname}\n" .
+    $self->chat("cpanm ($self->{name}) $VERSION on perl $] built for $Config{archname}\n" .
                 "Work directory is $self->{base}\n");
 }
 
@@ -578,7 +572,7 @@ sub load_argv_from_fh {
 sub show_version {
     my $self = shift;
 
-    print "cpanm (Menlo) version $VERSION ($0)\n";
+    print "cpanm ($self->{name}) version $VERSION ($0)\n";
     print "perl version $] ($^X)\n\n";
 
     print "  \%Config:\n";
@@ -2246,7 +2240,7 @@ sub static_install_configure {
     my $args = $depth == 0 ? $self->{build_args}{configure} : [];
 
     require Menlo::Builder::Static;
-    my $builder = Menlo::Builder::Static->new;
+    my $builder = Menlo::Builder::Static->new(meta => $dist->{cpanmeta});
     $self->configure(sub { $builder->configure($args || []) }, $depth);
 
     $state->{configured_ok} = 1;
